==> grokcore.formlib-1.4.tar.gz: grokcore.formlib-1.4/setup.py <==
from setuptools import setup, find_packages
import os

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('README.txt')
    + '\n' +
    read('CHANGES.txt')
    )

setup(
    name='grokcore.formlib',
    version = '1.4',
    author='Grok Team',
    author_email='grok-dev@zope.org',
    url='http://grok.zope.org',
    download_url='http://cheeseshop.python.org/pypi/grokcore.formlib',
    description='Grok-like configuration for zope.formlib components',
    long_description=long_description,
    license='ZPL',
    classifiers=['Environment :: Web Environment',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: Zope Public License',
                 'Programming Language :: Python',
                 'Framework :: Zope3',
                 ],

    packages=find_packages('src'),
    package_dir = {'': 'src'},
    namespace_packages=['grokcore'],
    include_package_data = True,
    zip_safe=False,
    install_requires=['setuptools',
                      'martian >= 0.10',
                      'grokcore.component >= 1.5',
                      'grokcore.security >= 1.2',
                      'grokcore.view >= 1.12',
                      'zope.formlib',
                      # for tests:
                      'zope.testing',
                      'zope.lifecycleevent',
                      'zope.securitypolicy',
                      'zope.app.zcmlfiles',
                      ],
)

==> grokcore.formlib-1.5.tar.gz: grokcore.formlib-1.5/setup.py <==
from setuptools import setup, find_packages
import os

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('README.txt')
    + '\n' +
    read('CHANGES.txt')
    )

tests_require = [
    'zope.app.testing',
    'zope.app.zcmlfiles',
    'zope.component',
    'zope.configuration',
    'zope.securitypolicy',
    'zope.testbrowser',
    'zope.testing',
    ]

setup(
    name='grokcore.formlib',
    version = '1.5',
    author='Grok Team',
    author_email='grok-dev@zope.org',
    url='http://grok.zope.org',
    download_url='http://cheeseshop.python.org/pypi/grokcore.formlib',
    description='Grok-like configuration for zope.formlib components',
    long_description=long_description,
    license='ZPL',
    classifiers=['Environment :: Web Environment',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: Zope Public License',
                 'Programming Language :: Python',
                 'Framework :: Zope3',
                 ],

    packages=find_packages('src'),
    package_dir = {'': 'src'},
    namespace_packages=['grokcore'],
    include_package_data = True,
    zip_safe=False,
    install_requires=['setuptools',
                      'grokcore.component >= 1.5',
                      'grokcore.security >= 1.2',
                      'grokcore.view >= 1.12',
                      'martian >= 0.10',
                      'pytz',
                      'zope.container',
                      'zope.event',
                      'zope.formlib',
                      'zope.interface',
                      'zope.lifecycleevent',
                      'zope.publisher',
                      'zope.schema',
                      ],
    tests_require=tests_require,
    extras_require={'test': tests_require},
)
